==> datareadr-0.10.1.tar.gz: datareadr-0.10.1/README.md <==
# DataReadr
DataReadr with GUI Interface simplifies the process of adding Pandas code into Python scripts. Through a user-friendly GUI, users can easily select and insert Pandas functions, automating repetitive tasks and enhancing productivity in data analysis projects.

# Examples of How To Use (Beta Version Not Fully Completed)

Loading UI
```python
import datareadr as dr

#loading the ui
dr.load_ui(__file__) #__file__ (takes the current file location and insert it in the program)
```
Delete the 'load_ui' code line when dataframe is imported.

# How To Use The UI!

# Step 1
Selecting any file you want to import.

![Screenshot 2024-09-28 101847](https://github.com/user-attachments/assets/7c49cdef-b964-4190-acfe-c96d97e8361c)

# Step 2
Click on browse file and then select the file you want to import.

![Screenshot 2024-09-28 101918](https://github.com/user-attachments/assets/a9428945-130b-43bf-981b-bd5e02461c96)

# Step 3
Then Click on check, Then the program will check your file and show the data.

![Screenshot 2024-09-28 101945](https://github.com/user-attachments/assets/a8941177-8607-4ae5-9b05-ee90469cf0e4)

# Step 4
Now Click on import and your file will we imported.

![Screenshot 2024-09-28 102006](https://github.com/user-attachments/assets/b7780fb9-34d6-4f05-950e-af823ab2187a)

# Step 5
This message show's that you're file is successfully imported. Enjoy!

![Screenshot 2024-09-28 102031](https://github.com/user-attachments/assets/29f948a2-84da-4ae3-bb89-4fe06253e4a5)

==> datareadr-0.11.5.tar.gz: datareadr-0.11.5/README.md <==
# DataReadr
DataReadr with GUI Interface simplifies the process of adding Pandas code into Python scripts. Through a user-friendly GUI, users can easily select and insert Pandas functions, automating repetitive tasks and enhancing productivity in data analysis projects.

# Examples of How To Use (Beta Version Not Fully Completed)

Loading UI
```python
import datareadr as dr # pip install datareadr
import sys # preinstalled in python

#loading the ui
dr.load_ui(sys.argv[0]) #sys.argv[0] (takes the current file location and insert it in the program)
```
Delete the 'load_ui' code line when dataframe is imported.

# How To Use The UI!

# Step 1
Selecting any file you want to import.

![Screenshot 2024-09-28 101847](https://github.com/user-attachments/assets/7c49cdef-b964-4190-acfe-c96d97e8361c)

# Step 2
Click on browse file and then select the file you want to import.

![Screenshot 2024-09-28 101918](https://github.com/user-attachments/assets/a9428945-130b-43bf-981b-bd5e02461c96)

# Step 3
Then Click on check, Then the program will check your file and show the data.

![Screenshot 2024-09-28 101945](https://github.com/user-attachments/assets/a8941177-8607-4ae5-9b05-ee90469cf0e4)

# Step 4
Now Click on import and your file will we imported.

![Screenshot 2024-09-28 102006](https://github.com/user-attachments/assets/b7780fb9-34d6-4f05-950e-af823ab2187a)

# Step 5
This message show's that you're file is successfully imported. Enjoy!

![Screenshot 2024-09-28 102031](https://github.com/user-attachments/assets/29f948a2-84da-4ae3-bb89-4fe06253e4a5)
